@@ -7,6 +7,7 @@
 #######################################################################
 
 import os
+import pathlib
 from collections import namedtuple
 from collections.abc import Mapping, MutableMapping
 
@@ -20,7 +21,7 @@ class vlmeta(MutableMapping, blosc2_ext.vlmeta):
     def __init__(self, schunk, urlpath, mode):
         self.urlpath = urlpath
         self.mode = mode
-        super(vlmeta, self).__init__(schunk)
+        super().__init__(schunk)
 
     def __setitem__(self, name, content):
         blosc2_ext.check_access_mode(self.urlpath, self.mode)
@@ -31,20 +32,20 @@ class vlmeta(MutableMapping, blosc2_ext.vlmeta):
             strict_types=True,
             use_bin_type=True,
         )
-        super(vlmeta, self).set_vlmeta(name, content, **cparams)
+        super().set_vlmeta(name, content, **cparams)
 
     def __getitem__(self, name):
-        return unpackb(super(vlmeta, self).get_vlmeta(name), list_hook=blosc2_ext.decode_tuple)
+        return unpackb(super().get_vlmeta(name), list_hook=blosc2_ext.decode_tuple)
 
     def __delitem__(self, name):
         blosc2_ext.check_access_mode(self.urlpath, self.mode)
-        super(vlmeta, self).del_vlmeta(name)
+        super().del_vlmeta(name)
 
     def __len__(self):
-        return super(vlmeta, self).nvlmetalayers()
+        return super().nvlmetalayers()
 
     def __iter__(self):
-        keys = super(vlmeta, self).get_names()
+        keys = super().get_names()
         yield from keys
 
     def getall(self):
@@ -52,7 +53,7 @@ class vlmeta(MutableMapping, blosc2_ext.vlmeta):
         Return all the variable length metalayers as a dictionary
 
         """
-        return super(vlmeta, self).to_dict()
+        return super().to_dict()
 
 
 class Meta(Mapping):
@@ -198,11 +199,9 @@ class SChunk(blosc2_ext.SChunk):
             "mode",
             "_is_view",
         ]
-        all_allowed_kwargs = all(kwarg in allowed_kwargs for kwarg in kwargs.keys())
-        if not all_allowed_kwargs:
-            for kwarg in kwargs.keys():
-                if kwarg not in allowed_kwargs:
-                    raise ValueError(f"{kwarg} is not supported as keyword argument")
+        for kwarg in kwargs:
+            if kwarg not in allowed_kwargs:
+                raise ValueError(f"{kwarg} is not supported as keyword argument")
         urlpath = kwargs.get("urlpath")
         if "contiguous" not in kwargs:
             # Make contiguous true for disk, else sparse (for in-memory performance)
@@ -225,17 +224,20 @@ class SChunk(blosc2_ext.SChunk):
         if chunksize is None:
             chunksize = 2**24
             if data is not None:
-                chunksize = data.size * data.itemsize
-                # Make that a multiple of typesize
-                chunksize = chunksize // data.itemsize * data.itemsize
+                if hasattr(data, "itemsize"):
+                    chunksize = data.size * data.itemsize
+                    # Make that a multiple of typesize
+                    chunksize = chunksize // data.itemsize * data.itemsize
+                else:
+                    chunksize = len(data)
             # Use a cap of 256 MB (modern boxes should all have this RAM available)
             if chunksize > 2**28:
                 chunksize = 2**28
 
-        super(SChunk, self).__init__(_schunk=sc, chunksize=chunksize, data=data, **kwargs)
-        self.vlmeta = vlmeta(super(SChunk, self).c_schunk, self.urlpath, self.mode)
-        self._cparams = super(SChunk, self).get_cparams()
-        self._dparams = super(SChunk, self).get_dparams()
+        super().__init__(_schunk=sc, chunksize=chunksize, data=data, **kwargs)
+        self.vlmeta = vlmeta(super().c_schunk, self.urlpath, self.mode)
+        self._cparams = super().get_cparams()
+        self._dparams = super().get_dparams()
 
     @property
     def cparams(self):
@@ -246,8 +248,8 @@ class SChunk(blosc2_ext.SChunk):
 
     @cparams.setter
     def cparams(self, value):
-        super(SChunk, self).update_cparams(value)
-        self._cparams = super(SChunk, self).get_cparams()
+        super().update_cparams(value)
+        self._cparams = super().get_cparams()
 
     @property
     def dparams(self):
@@ -258,8 +260,8 @@ class SChunk(blosc2_ext.SChunk):
 
     @dparams.setter
     def dparams(self, value):
-        super(SChunk, self).update_dparams(value)
-        self._dparams = super(SChunk, self).get_dparams()
+        super().update_dparams(value)
+        self._dparams = super().get_dparams()
 
     @property
     def meta(self):
@@ -296,7 +298,7 @@ class SChunk(blosc2_ext.SChunk):
         1
         """
         blosc2_ext.check_access_mode(self.urlpath, self.mode)
-        return super(SChunk, self).append_data(data)
+        return super().append_data(data)
 
     def fill_special(self, nitems, special_value):
         """Fill the SChunk with a special value.  SChunk must be empty.
@@ -321,7 +323,7 @@ class SChunk(blosc2_ext.SChunk):
         """
         if not isinstance(special_value, SpecialValue):
             raise ValueError("special_value must be a SpecialValue instance")
-        nchunks = super(SChunk, self).fill_special(nitems, special_value.value)
+        nchunks = super().fill_special(nitems, special_value.value)
         if nchunks < 0:
             raise RuntimeError("Unable to fill with special values")
         return nchunks
@@ -368,7 +370,7 @@ class SChunk(blosc2_ext.SChunk):
         >>> bytes_obj == buffer
         True
         """
-        return super(SChunk, self).decompress_chunk(nchunk, dst)
+        return super().decompress_chunk(nchunk, dst)
 
     def get_chunk(self, nchunk):
         """Return the compressed chunk that is in the SChunk.
@@ -388,7 +390,7 @@ class SChunk(blosc2_ext.SChunk):
         RunTimeError
             If some problem is detected.
         """
-        return super(SChunk, self).get_chunk(nchunk)
+        return super().get_chunk(nchunk)
 
     def delete_chunk(self, nchunk):
         """Delete the specified chunk from the SChunk.
@@ -409,7 +411,7 @@ class SChunk(blosc2_ext.SChunk):
             If some problem was detected.
         """
         blosc2_ext.check_access_mode(self.urlpath, self.mode)
-        return super(SChunk, self).delete_chunk(nchunk)
+        return super().delete_chunk(nchunk)
 
     def insert_chunk(self, nchunk, chunk):
         """Insert an already compressed chunk in the SChunk.
@@ -432,7 +434,7 @@ class SChunk(blosc2_ext.SChunk):
             If some problem was detected.
         """
         blosc2_ext.check_access_mode(self.urlpath, self.mode)
-        return super(SChunk, self).insert_chunk(nchunk, chunk)
+        return super().insert_chunk(nchunk, chunk)
 
     def insert_data(self, nchunk, data, copy):
         """Insert the data in the specified position in the SChunk.
@@ -457,7 +459,7 @@ class SChunk(blosc2_ext.SChunk):
             If some problem was detected.
         """
         blosc2_ext.check_access_mode(self.urlpath, self.mode)
-        return super(SChunk, self).insert_data(nchunk, data, copy)
+        return super().insert_data(nchunk, data, copy)
 
     def update_chunk(self, nchunk, chunk):
         """Update an existing chunk in the SChunk.
@@ -480,7 +482,7 @@ class SChunk(blosc2_ext.SChunk):
             If some problem was detected.
         """
         blosc2_ext.check_access_mode(self.urlpath, self.mode)
-        return super(SChunk, self).update_chunk(nchunk, chunk)
+        return super().update_chunk(nchunk, chunk)
 
     def update_data(self, nchunk, data, copy):
         """Update the chunk in the :paramref:`nchunk`-th position with the given data.
@@ -505,7 +507,7 @@ class SChunk(blosc2_ext.SChunk):
             If some problem was detected.
         """
         blosc2_ext.check_access_mode(self.urlpath, self.mode)
-        return super(SChunk, self).update_data(nchunk, data, copy)
+        return super().update_data(nchunk, data, copy)
 
     def get_slice(self, start=0, stop=None, out=None):
         """Get a slice from :paramref:`start` to :paramref:`stop`.
@@ -546,7 +548,7 @@ class SChunk(blosc2_ext.SChunk):
         :func:`__getitem__`
 
         """
-        return super(SChunk, self).get_slice(start, stop, out)
+        return super().get_slice(start, stop, out)
 
     def __getitem__(self, item):
         """Get a slice from the SChunk.
@@ -617,7 +619,7 @@ class SChunk(blosc2_ext.SChunk):
         if key.step is not None and key.step != 1:
             raise IndexError("`step` must be 1")
         blosc2_ext.check_access_mode(self.urlpath, self.mode)
-        return super(SChunk, self).set_slice(start=key.start, stop=key.stop, value=value)
+        return super().set_slice(start=key.start, stop=key.stop, value=value)
 
     def to_cframe(self):
         """Get a bytes object containing the serialized :ref:`SChunk <SChunk>` instance.
@@ -632,7 +634,7 @@ class SChunk(blosc2_ext.SChunk):
         :func:`~blosc2.schunk_from_cframe`
 
         """
-        return super(SChunk, self).to_cframe()
+        return super().to_cframe()
 
     def iterchunks(self, dtype):
         """
@@ -760,7 +762,7 @@ class SChunk(blosc2_ext.SChunk):
         out: None
 
         """
-        return super(SChunk, self).remove_postfilter(func_name)
+        return super().remove_postfilter(func_name)
 
     def filler(self, inputs_tuple, schunk_dtype, nelem=None):
         """Decorator to set a filler function.
@@ -920,13 +922,13 @@ class SChunk(blosc2_ext.SChunk):
         out: None
 
         """
-        return super(SChunk, self).remove_prefilter(func_name)
+        return super().remove_prefilter(func_name)
 
     def __dealloc__(self):
-        super(SChunk, self).__dealloc__()
+        super().__dealloc__()
 
 
-def open(urlpath, mode="a", **kwargs):
+def open(urlpath, mode="a", offset=0, **kwargs):
     """Open a persistent :ref:`SChunk <SChunk>` (or :ref:`NDArray <NDArray>`).
 
     Parameters
@@ -936,6 +938,9 @@ def open(urlpath, mode="a", **kwargs):
         is stored.
     mode: str, optional
         The open mode.
+    offset: int, optional
+        An offset in the file where super-chunk or array data is located
+        (e.g. in a file containing several such objects).
 
     Other parameters
     ----------------
@@ -949,6 +954,11 @@ def open(urlpath, mode="a", **kwargs):
             A dictionary with the decompression parameters, which are the same that can
             be used in the :func:`~blosc2.decompress2` function.
 
+    Notes
+    -----
+    This is just a 'logical' open, so no there is not a `close()` counterpart because
+    currently there is no need for it.
+
     Returns
     -------
     out: :ref:`SChunk <SChunk>` or :ref:`NDArray <NDArray>`
@@ -980,6 +990,8 @@ def open(urlpath, mode="a", **kwargs):
     True
 
     """
+    if isinstance(urlpath, pathlib.PurePath):
+        urlpath = str(urlpath)
     if not os.path.exists(urlpath):
         raise FileNotFoundError(f"No such file or directory: {urlpath}")
-    return blosc2_ext.open(urlpath, mode, **kwargs)
+    return blosc2_ext.open(urlpath, mode, offset, **kwargs)
